==> haskell-resourcet-1.2.6-152-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resourcet
version:              1.2.6
visibility:           public
id:                   resourcet-1.2.6-sglnjXR7nZEbOURQ8qh5t
key:                  resourcet-1.2.6-sglnjXR7nZEbOURQ8qh5t
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  447630c8600f82ee3c90dfdc60c06f33
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resourcet
hs-libraries:         HSresourcet-1.2.6-sglnjXR7nZEbOURQ8qh5t
depends:
    base-4.17.2.1 containers-0.6.7 exceptions-0.10.5 mtl-2.2.2
    primitive-0.9.1.0-IzoEy6gcvXy7FAbkwCq547 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.2.6-153-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resourcet
version:              1.2.6
visibility:           public
id:                   resourcet-1.2.6-1DDiq5XD7CWDw9CwnQya4j
key:                  resourcet-1.2.6-1DDiq5XD7CWDw9CwnQya4j
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  5745171a3db78172573a52824b7333c9
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resourcet
hs-libraries:         HSresourcet-1.2.6-1DDiq5XD7CWDw9CwnQya4j
depends:
    base-4.17.2.1 containers-0.6.7 exceptions-0.10.5 mtl-2.2.2
    primitive-0.9.1.0-ICFc9Oc8RCqLS4oNEzcX43 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
